@@ -212,23 +212,23 @@ summary.row <- function(data,var,st,
     mat <- as.data.frame(table(va))
     propcalc <- mat$Freq/nonmiss
     if (!is.null(wts) & grepl('wts',summ[2])) {
-      propcalc <- sapply(mat$va, function(x) stats::weighted.mean(va == x, w = wts))
+      propcalc <- sapply(mat$va, function(x) stats::weighted.mean(va == x, w = wts, na.rm = TRUE))
     }
     propcalc <- propcalc*(100^factor.percent)
     mat$va <- paste('...',mat$va)
     if (fixed.digits) {
       mat$Prop <- sapply(1:length(propcalc), function(x)
         format(propcalc[x],
-               digits=max(digits[2]-2*factor.percent,0),
+               digits=max(digits[2]-2*factor.percent,1),
                nsmall=max(digits[2]-2*factor.percent,0),
                scientific = FALSE))
       mat$Freq <- sapply(1:length(mat$Freq), function(x)
         format(as.numeric(mat$Freq[x]),
-               digits=digits[1],
+               digits=max(digits[1],1),
                nsmall=digits[1],
                scientific = FALSE))
       st[1,2] <- format(as.numeric(st[1,2]),
-                                   digits = digits[1],
+                                   max(digits = digits[1],1),
                                    nsmall = digits[1],
                         scientific = FALSE)
     } else {
@@ -257,11 +257,11 @@ summary.row <- function(data,var,st,
     facnames <- paste('...',levels(va))
     #Run each of the functions on the variable and get results
     results <- lapply(1:ncol(mat),
-                      function(x) sapply(summ, function(y) parsefcn_summ(mat[,x],y, wts = wts)))
+                      function(x) sapply(summ, function(y) parsefcn_summ(mat[,x],y, wts = wts[!is.na(va)])))
     #Round
     if (fixed.digits) {
       results <- lapply(results, function(x)
-        sapply(1:length(x), function(y) format(x[y],digits=digits[y],nsmall = digits[y],scientific=FALSE)))
+        sapply(1:length(x), function(y) format(x[y],digits=digits[y],nsmall = max(digits[y],1),scientific=FALSE)))
     } else {
       results <- lapply(results, function(x)
         sapply(1:length(x), function(y) as.character(round(x[y],digits=digits[y]))))
@@ -277,13 +277,13 @@ summary.row <- function(data,var,st,
     va <- data[[var]]
 
     #Run each of the functions on the variable and get results
-    results <- sapply(summ, function(y) parsefcn_summ(va,y, wts = wts))
+    results <- sapply(summ, function(y) parsefcn_summ(va,y, wts = wts[!is.na(va)]))
 
     #Round
     if (fixed.digits) {
-      results <- sapply(1:length(results), function(y) format(results[y],digits=digits[y],nsmall = digits[y],scientific = FALSE))
+      results <- sapply(1:length(results), function(y) format(results[y],digits=max(digits[y],1),nsmall = digits[y],scientific = FALSE))
     } else {
-      results <- sapply(1:length(results), function(y) round(results[y],digits=digits[y]))
+      results <- sapply(1:length(results), function(y) round(results[y],digits=max(digits[y],1)))
     }
     #And construct
     st[1,] <- c(title,results)
